obelisk.types
=============

.. automodule:: obelisk.types

   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      Datapoint
      IngestMode
      ObeliskKind
      QueryResult
      TimestampPrecision
   